@@ -10,6 +10,8 @@ import os
 import copy
 from collections import namedtuple
 from dataclasses import dataclass
+from typing import List
+
 from datetime import datetime
 from loguru import logger
 
@@ -28,7 +30,6 @@ class Match:
     league: str = ''
 
 
-
 @dataclass
 class MatchBet(Match):
     hdc: float = ''
@@ -37,6 +38,18 @@ class MatchBet(Match):
     odd_away: float = ''
     source: str = ''
     
+@dataclass    
+class PrevMatch(Match):
+    score_home: str = ''
+    score_away: str = ''
+    
+@dataclass    
+class MatchPreview(Match):
+    prev_meets: List[PrevMatch] = None
+    latest_matches_home: List[PrevMatch] = None
+    latest_matches_away: List[PrevMatch] = None
+    
+    
 
 def team_name_revise0(team, source_input, source_output):
     
